@@ -6,115 +6,110 @@ import aiohttp
 import url_regex
 
 from . import http
-from .classes import Colour
-from .classes import Steam
+from .classes import Colour, Steam, Image, Icon
+from typing import Union
 
 
 class BadRequest(Exception):
     pass
 
+
 class NotFound(Exception):
     pass
 
+
 class Client:
     _BASE_URL = "https://api.alexflipnote.dev/"
 
     def __init__(self):
         self._http_client = http
 
-    def api_url(self, path):
+    def _api_url(self, path):
         return self._BASE_URL + path
 
-    async def to_bytes(self, url):
-        read_url = await self._http_client.get(str(url), res_method = "read")
-        bio = io.BytesIO(read_url)
-        bio.seek(0)
-        return bio
-
-    async def achievement(self, text, icon: int = "", return_bytes=False):
+    async def achievement(self, text, icon: Union[int, str, Icon] = None):
+        text = text.replace(" ", "%20").replace("#", "%23")
+        actual_icon = ""
         if icon is not None:
-            icon = f"&icon={icon}"
+            if isinstance(icon, int):
+                actual_icon = Icon(icon).value
 
-        url = self.api_url(f"achievement?text={text}{icon}")
+            elif isinstance(icon, str):
+                actual_icon = Icon[icon].value
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
+            elif isinstance(icon, Icon):
+                actual_icon = Icon.value
 
-        return url
+        if icon is not None:
+            actual_icon = f"&icon={actual_icon}"
 
-    async def amiajoke(self, image: str, return_bytes=False):
+        url = self._api_url(f"achievement?text={text}{actual_icon}")
+
+        return Image(url, self._http_client)
+
+    async def amiajoke(self, image: str):
         get_url = url_regex.UrlRegex(str(image))
         if not get_url.detect:
             raise BadRequest("String passed is not a valid URL.")
         if get_url.links[0].domain != "cdn.discordapp.com":
             raise BadRequest("Only Discord CDN URLs are allowed...")
 
-        url = self.api_url("amiajoke?image={image}")
+        url = self._api_url("amiajoke?image={image}")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
+        return Image(url, self._http_client)
 
-        return url
-
-    async def bad(self, image: str, return_bytes=False):
+    async def bad(self, image: str):
         get_url = url_regex.UrlRegex(str(image))
         if not get_url.detect:
             raise BadRequest("String passed is not a valid URL.")
         if get_url.links[0].domain != "cdn.discordapp.com":
             raise BadRequest("Only Discord CDN URLs are allowed...")
 
-        url = self.api_url("bad?image={image}")
+        url = self._api_url("bad?image={image}")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
+        return Image(url, self._http_client)
 
-        return url
-
-    @property
     async def birb(self):
-        url = await self._http_client.get(self.api_url("bad"), res_method = "json")
+        url = await self._http_client.get(self._api_url("birb"), res_method = "json")
+
         return url['file']
 
-    async def calling(self, text, return_bytes):
+    async def calling(self, text):
         text = text.replace(" ", "%20").replace("#", "%23")
-        url = self.api_url(f"calling?text={text}")
+        url = self._api_url(f"calling?text={text}")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
+        return Image(url, self._http_client)
 
-        return url
-
-    async def captcha(self, text, return_bytes):
+    async def captcha(self, text):
         text = text.replace(" ", "%20").replace("#", "%23")
-        url = self.api_url(f"captcha?text={text}")
+        url = self._api_url(f"captcha?text={text}")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
+        return Image(url, self._http_client)
 
-        return url
-
-    @property
     async def cats(self):
-        url = await self._http_client.get(self.api_url("cats"), res_method = "json")
+        url = await self._http_client.get(self._api_url("cats"), res_method = "json")
+
         return url['file']
 
-    async def challenge(self, text, icon: int = "", return_bytes=False):
-        if icon is not None:
-            icon = f"&icon={icon}"
-
+    async def challenge(self, text, icon: Union[int, str, Icon] = None):
         text = text.replace(" ", "%20").replace("#", "%23")
-        url = self.api_url(f"challenge?text={text}{icon}")
+        actual_icon = ""
+        if icon is not None:
+            if isinstance(icon, int):
+                actual_icon = Icon(icon).value
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
+            elif isinstance(icon, str):
+                actual_icon = Icon[icon].value
 
-        return url
+            elif isinstance(icon, Icon):
+                actual_icon = Icon.value
+
+        if icon is not None:
+            actual_icon = f"&icon={actual_icon}"
+
+        url = self._api_url(f"challenge?text={text}{actual_icon}")
+
+        return Image(url, self._http_client)
 
     async def colour(self, colour=None):
         if colour is None:
@@ -124,7 +119,7 @@ class Client:
             raise BadRequest("Invalid HEX value. You're only allowed to enter HEX (0-9 & A-F)")
 
         response = await self._http_client.get(
-            str(self.api_url(f"colour/{colour}")),
+            str(self._api_url(f"colour/{colour}")),
             res_method = "json"
         )
         return Colour(response)
@@ -132,44 +127,37 @@ class Client:
     color = colour  # aliases to colour
 
     async def github_colours(self):
-        url = self.api_url("color/github")
-        return url
+        response = await self._http_client.get(str(self._api_url("color/github")), res_method = "json")
 
-    github_colour = github_colours  # aliases to github_colour
+        return response
 
-    async def colour_image(self, colour=None, return_bytes=False):
+    github_color = github_colours  # aliases to github_colour
+
+    async def colour_image(self, colour=None):
         if colour is None:
             colour = "%06x" % random.randint(0, 0xFFFFFF)
 
         if not re.search(r'^(?:[0-9a-fA-F]{3}){1,2}$', colour):
             raise BadRequest("Invalid HEX value. You're only allowed to enter HEX (0-9 & A-F)")
 
-        url = self.api_url(f"colour/image/colour")
+        url = self._api_url(f"colour/image/colour")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
-
-        return url
+        return Image(url, self._http_client)
 
     color_image = colour_image  # aliases to colour_image
 
-    async def colour_image_gradient(self, colour=None, return_bytes=False):
+    async def colour_image_gradient(self, colour=None):
         if colour is None:
             colour = "%06x" % random.randint(0, 0xFFFFFF)
 
         if not re.search(r'^(?:[0-9a-fA-F]{3}){1,2}$', colour):
             raise BadRequest("Invalid HEX value. You're only allowed to enter HEX (0-9 & A-F)")
 
-        url = self.api_url(f"colour/image/gradient/{colour}")
+        url = self._api_url(f"colour/image/gradient/{colour}")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
+        return Image(url, self._http_client)
 
-        return url
-
-    async def colourify(self, image, colour="", background="", return_bytes=False):
+    async def colourify(self, image, colour="", background=""):
         get_url = url_regex.UrlRegex(str(image))
         if not get_url.detect:
             raise BadRequest("String passed is not a valid URL.")
@@ -186,53 +174,37 @@ class Client:
 
             background = f"&b={background}"
 
-        url = self.api_url(f"colourify?image={image}{colour}{background}")
+        url = self._api_url(f"colourify?image={image}{colour}{background}")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
+        return Image(url, self._http_client)
 
-        return url
-
-    async def didyoumean(self, top, bottom, return_bytes=False):
+    async def didyoumean(self, top, bottom):
         top = top.replace(" ", "%20").replace("#", "%23")
         bottom = bottom.replace(" ", "%20").replace("#", "%23")
 
-        url = self.api_url(f"didyoumean?top={top}&bottom={bottom}")
+        url = self._api_url(f"didyoumean?top={top}&bottom={bottom}")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
+        return Image(url, self._http_client)
 
-        return url
-
-    @property
     async def dogs(self):
-        url = await self._http_client.get(self.api_url("dogs"), res_method = "json")
+        url = await self._http_client.get(self._api_url("dogs"), res_method = "json")
+
         return url['file']
 
-    async def drake(self, top, bottom, return_bytes=False):
+    async def drake(self, top, bottom):
         top = top.replace(" ", "%20").replace("#", "%23")
         bottom = bottom.replace(" ", "%20").replace("#", "%23")
-        url = self.api_url(f"drake?top={top}&bottom={bottom}")
+        url = self._api_url(f"drake?top={top}&bottom={bottom}")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
+        return Image(url, self._http_client)
 
-        return url
-
-    async def facts(self, text, return_bytes=False):
+    async def facts(self, text):
         text = text.replace(" ", "%20").replace("#", "%23")
-        url = self.api_url(f"facts?text={text}")
+        url = self._api_url(f"facts?text={text}")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
+        return Image(url, self._http_client)
 
-        return url
-
-    async def filter(self, name, image: str, return_bytes=False):
+    async def filter(self, name, image: str):
         options = ['blur', 'invert', 'b&w', 'deepfry', 'snow', 'gay',
                    'pixelate', 'jpegify', 'magik', 'communist']
         if name not in options:
@@ -244,88 +216,65 @@ class Client:
         if get_url.links[0].domain != "cdn.discordapp.com":
             raise BadRequest("Only Discord CDN URLs are allowed...")
 
-        url = self.api_url(f"filter/{name}?image={image}")
+        url = self._api_url(f"filter/{name}?image={image}")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
+        return Image(url, self._http_client)
 
-        return url
-
-    async def floor(self, text, image: str = None, return_bytes=False):
+    async def floor(self, text, image: str = None):
         text = text.replace(" ", "%20").replace("#", "%23")
         if image is not None:
             get_url = url_regex.UrlRegex(str(image))
             if not get_url.detect:
                 raise BadRequest("String passed is not a valid URL.")
             image = f"&image={image}"
-        url = self.api_url(f"floor?text={text}{image}")
+        url = self._api_url(f"floor?text={text}{image}")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
-        return url
+        return Image(url, self._http_client)
 
-    @property
     async def fml(self):
-        url = await self._http_client.get(self.api_url("fml"), res_method = "json")
-        return url['text']
+        url = await self._http_client.get(self._api_url("fml"), res_method = "json")
 
-    async def jokeoverhead(self, image: str, return_bytes=False):
+        return url.get("text")
+
+    async def jokeoverhead(self, image: str):
         get_url = url_regex.UrlRegex(str(image))
         if not get_url.detect:
             raise BadRequest("String passed is not a valid URL.")
         if get_url.links[0].domain != "cdn.discordapp.com":
             raise BadRequest("Only Discord CDN URLs are allowed...")
-        url = self.api_url(f"jokeoverhead?image={image}")
+        url = self._api_url(f"jokeoverhead?image={image}")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
+        return Image(url, self._http_client)
 
-        return url
-
-    async def pornhub(self, text, text2, return_bytes=False):
+    async def pornhub(self, text, text2):
         text = text.replace(" ", "%20").replace("#", "%23")
         text2 = text2.replace(" ", "%20").replace("#", "%23")
-        url = self.api_url(f"pornhub?text={text}&text2={text2}")
+        url = self._api_url(f"pornhub?text={text}&text2={text2}")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
+        return Image(url, self._http_client)
 
-        return url
-
-    @property
     async def sadcat(self):
-        url = await self._http_client.get(self.api_url("sadcat"), res_method = "json")
+        url = await self._http_client.get(self._api_url("sadcat"), res_method = "json")
+
         return url['file']
 
-    async def salty(self, image: str, return_bytes=False):
+    async def salty(self, image: str):
         get_url = url_regex.UrlRegex(str(image))
         if not get_url.detect:
             raise BadRequest("String passed is not a valid URL.")
         if get_url.links[0].domain != "cdn.discordapp.com":
             raise BadRequest("Only Discord CDN URLs are allowed...")
-        url = self.api_url(f"salty?image={image}")
+        url = self._api_url(f"salty?image={image}")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
+        return Image(url, self._http_client)
 
-        return url
-
-    async def scroll(self, text, return_bytes=False):
+    async def scroll(self, text):
         text = text.replace(" ", "%20").replace("#", "%23")
-        url = self.api_url(f"scroll?text={text}")
+        url = self._api_url(f"scroll?text={text}")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
+        return Image(url, self._http_client)
 
-        return url
-
-    async def ship(self, user: str, user2: str, return_bytes=False):
+    async def ship(self, user: str, user2: str):
         user_url = url_regex.UrlRegex(str(user))
         if not user_url.detect:
             raise BadRequest("String passed is not a valid URL.")
@@ -338,23 +287,19 @@ class Client:
         if user2_url.links[0].domain != "cdn.discordapp.com":
             raise BadRequest("Only Discord CDN URLs are allowed...")
 
-        url = self.api_url(f"ship?user={user}&user2={user2}")
+        url = self._api_url(f"ship?user={user}&user2={user2}")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
-
-        return url
+        return Image(url, self._http_client)
 
     async def steam(self, profile):
         try:
-            response = await self._http_client.get(self.api_url(f"steam/user/{profile}"), res_method = "json")
+            response = await self._http_client.get(self._api_url(f"steam/user/{profile}"), res_method = "json")
         except aiohttp.ContentTypeError:
             raise NotFound("User not found on steam.")
 
         return Steam(response)
 
-    async def supreme(self, text, dark=False, light=False, return_bytes=False):
+    async def supreme(self, text, dark=False, light=False):
         text = text.replace(" ", "%20").replace("#", "%23")
         darkorlight = ""
         if dark:
@@ -364,15 +309,11 @@ class Client:
         if dark and light:
             raise BadRequest("You can only choose either light or dark, not both.")
 
-        url = self.api_url(f"supreme?text={text}{darkorlight}")
+        url = self._api_url(f"supreme?text={text}{darkorlight}")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
+        return Image(url, self._http_client)
 
-        return url
-
-    async def trash(self, face: str, trash: str, return_bytes=False):
+    async def trash(self, face: str, trash: str):
         user_url = url_regex.UrlRegex(str(face))
         if not user_url.detect:
             raise BadRequest("String passed is not a valid URL.")
@@ -385,10 +326,9 @@ class Client:
         if user2_url.links[0].domain != "cdn.discordapp.com":
             raise BadRequest("Only Discord CDN URLs are allowed...")
 
-        url = self.api_url(f"trash?user={face}&user2={trash}")
+        url = self._api_url(f"trash?user={face}&user2={trash}")
 
-        if return_bytes:
-            image_bytes = await self.to_bytes(url)
-            return image_bytes
+        return Image(url, self._http_client)
 
-        return url
+    async def close(self):
+        await self._http_client.close()
