@@ -4,8 +4,6 @@ import asyncio
 
 import aiohttp
 
-from . import cache
-
 
 # Removes the aiohttp ClientSession instance warning.
 class HTTPSession(aiohttp.ClientSession):
@@ -18,12 +16,6 @@ class HTTPSession(aiohttp.ClientSession):
 session = HTTPSession()
 
 
-async def close():
-    if not session.closed:
-        await session.close()
-
-
-@cache.async_cache()
 async def query(url, method="get", res_method="text", *args, **kwargs):
     async with getattr(session, method.lower())(url, *args, **kwargs) as res:
         return await getattr(res, res_method)()
@@ -35,3 +27,8 @@ async def get(url, *args, **kwargs):
 
 async def post(url, *args, **kwargs):
     return await query(url, "post", *args, **kwargs)
+
+
+async def close():
+    if not session.closed:
+        await session.close()
